@@ -1,6 +1,5 @@
 use 5.020;
 package Pg::BulkLoad;
-$Pg::BulkLoad::VERSION = '2.031';
 use feature qw/signatures postderef/;
 no warnings qw/experimental uninitialized/;
 use Try::Tiny;
@@ -11,6 +10,8 @@ use Data::Dumper;
 
 # ABSTRACT: Bulk Load for Postgres with ability to skip bad records.
 
+our $VERSION='2.04';
+
 sub new ( $Class, %args ) {
 	for my $required ( qw/ pg errorfile/ ) {	
 		unless ( $args{$required }) {			
@@ -24,7 +25,15 @@ sub new ( $Class, %args ) {
 	return $I;
 }
 
-sub _error ( $I, $msg, $row ) {
+# There was a live data run where no value was passed
+# for row, accepting undef for msg and row and then
+# croaking.
+sub _error ( $I, $msg=undef, $row=undef ) {
+	if( $msg eq undef ) { 
+			croak 'internal error no message, possible bug.'}
+	if( $row eq undef ) { 
+			croak 'internal error no row in scope, possible bad data format.'
+		}
 	$I->{errcount}++;
 	my $ERR = $I->{errors};
 	say $ERR $msg;
@@ -97,12 +106,14 @@ Pg::BulkLoad - Bulk Load for Postgres with ability to skip bad records.
 
 =head1 VERSION
 
-version 2.031
+version 2.04
 
 =head1 Pg::BulkLoad
 
 Load Comma and Tab Delimited files into Postgres, skipping bad records.
 
+=head1 VERSION 2.04
+
 =head1 Synopsis
 
  Shell> split -l 50000 -a 3 -d mydata.csv load
